@@ -41,7 +41,7 @@ public:
     {
     }
 
-    int rowForParentId(int parentid)
+    int rowForParentId(int parentid) const
     {
         const int grandparentid = tracker.parentId(parentid);
         int row = -1;
@@ -52,7 +52,7 @@ public:
             }
         } else {
             // offset of the parent in the list of children of the grandparent
-            row = tracker.jobNames(grandparentid).indexOf(tracker.jobForId(parentid));
+            row = tracker.rowForJob(parentid, grandparentid);
         }
         return row;
     }
@@ -66,10 +66,10 @@ public:
 JobTrackerModel::JobTrackerModel(const char *name, QObject *parent)
     : QAbstractItemModel(parent), d(new Private(name, this))
 {
-    connect(&d->tracker, SIGNAL(reset()),
-            this, SIGNAL(modelReset()));
+    connect(&d->tracker, &JobTracker::aboutToAdd,
+            this, &JobTrackerModel::jobAboutToBeAdded);
     connect(&d->tracker, &JobTracker::added,
-            this, &JobTrackerModel::jobsAdded);
+            this, &JobTrackerModel::jobAdded);
     connect(&d->tracker, &JobTracker::updated,
             this, &JobTrackerModel::jobsUpdated);
 }
@@ -79,20 +79,31 @@ JobTrackerModel::~JobTrackerModel()
     delete d;
 }
 
+JobTracker &JobTrackerModel::jobTracker()
+{
+    return d->tracker;
+}
+
 QModelIndex JobTrackerModel::index(int row, int column, const QModelIndex &parent) const
 {
+    if (column < 0 || column >= NumColumns) {
+        return QModelIndex();
+    }
     if (!parent.isValid()) { // session, at top level
         if (row < 0 || row >= d->tracker.sessions().size()) {
             return QModelIndex();
         }
         return createIndex(row, column, d->tracker.idForSession(d->tracker.sessions().at(row)));
     }
-    // non-toplevel job
-    const QStringList jobs = d->tracker.jobNames(parent.internalId());
-    if (row < 0 || row >= jobs.size()) {
+    if (parent.column() != 0) {
         return QModelIndex();
     }
-    return createIndex(row, column, d->tracker.idForJob(jobs.at(row)));
+    // job, i.e. non-toplevel
+    const int jobCount = d->tracker.jobCount(parent.internalId());
+    if (row < 0 || row >= jobCount) {
+        return QModelIndex();
+    }
+    return createIndex(row, column, d->tracker.jobIdAt(row, parent.internalId()));
 }
 
 QModelIndex JobTrackerModel::parent(const QModelIndex &idx) const
@@ -119,14 +130,17 @@ int JobTrackerModel::rowCount(const QModelIndex &parent) const
     if (!parent.isValid()) {
         return d->tracker.sessions().size();
     } else {
-        return d->tracker.jobNames(parent.internalId()).size();
+        if (parent.column() != 0) {
+            return 0;
+        }
+        return d->tracker.jobCount(parent.internalId());
     }
 }
 
 int JobTrackerModel::columnCount(const QModelIndex &parent) const
 {
     Q_UNUSED(parent);
-    return 7;
+    return NumColumns;
 }
 
 static QString formatTimeWithMsec(const QTime &time)
@@ -154,28 +168,32 @@ QVariant JobTrackerModel::data(const QModelIndex &idx, int role) const
         }
     } else { // not top level, so a job or subjob
         const int id = idx.internalId();
+        if (role != Qt::DisplayRole && role != Qt::ForegroundRole && role != Qt::FontRole && role != Qt::ToolTipRole && role != FailedIdRole) {
+            // Avoid the QHash lookup for all other roles
+            return QVariant();
+        }
         const JobInfo info = d->tracker.info(id);
         if (role == Qt::DisplayRole) {
             switch (idx.column()) {
-            case 0:
-                return info.id;
-            case 1:
+            case ColumnJobId:
+                return info.name;
+            case ColumnCreated:
                 return formatTimeWithMsec(info.timestamp.time());
-            case 2:
+            case ColumnWaitTime:
                 if (info.startedTimestamp.isNull() || info.timestamp.isNull()) {
                     return QString();
                 }
                 return formatDurationWithMsec(info.timestamp.msecsTo(info.startedTimestamp));
-            case 3:
+            case ColumnJobDuration:
                 if (info.endedTimestamp.isNull() || info.startedTimestamp.isNull()) {
                     return QString();
                 }
                 return formatDurationWithMsec(info.startedTimestamp.msecsTo(info.endedTimestamp));
-            case 4:
+            case ColumnJobType:
                 return info.type;
-            case 5:
+            case ColumnState:
                 return info.stateAsString();
-            case 6:
+            case ColumnInfo:
                 return info.debugString;
             }
         } else if (role == Qt::ForegroundRole) {
@@ -192,6 +210,8 @@ QVariant JobTrackerModel::data(const QModelIndex &idx, int role) const
             if (info.state == JobInfo::Failed) {
                 return info.error;
             }
+        } else if (role == FailedIdRole) {
+            return (info.state == JobInfo::Failed);
         }
     }
     return QVariant();
@@ -202,19 +222,19 @@ QVariant JobTrackerModel::headerData(int section, Qt::Orientation orientation, i
     if (role == Qt::DisplayRole) {
         if (orientation == Qt::Horizontal) {
             switch (section) {
-            case 0:
+            case ColumnJobId:
                 return QStringLiteral("Job ID");
-            case 1:
+            case ColumnCreated:
                 return QStringLiteral("Created");
-            case 2:
+            case ColumnWaitTime:
                 return QStringLiteral("Wait time");      // duration  (time started - time created)
-            case 3:
+            case ColumnJobDuration:
                 return QStringLiteral("Job duration");   // duration (time ended - time started)
-            case 4:
+            case ColumnJobType:
                 return QStringLiteral("Job Type");
-            case 5:
+            case ColumnState:
                 return QStringLiteral("State");
-            case 6:
+            case ColumnInfo:
                 return QStringLiteral("Info");
             }
         }
@@ -224,7 +244,9 @@ QVariant JobTrackerModel::headerData(int section, Qt::Orientation orientation, i
 
 void JobTrackerModel::resetTracker()
 {
-    d->tracker.triggerReset();
+    beginResetModel();
+    d->tracker.clear();
+    endResetModel();
 }
 
 bool JobTrackerModel::isEnabled() const
@@ -237,33 +259,28 @@ void JobTrackerModel::setEnabled(bool on)
     d->tracker.setEnabled(on);
 }
 
-void JobTrackerModel::jobsAdded(const QList< QPair< int, int > > &jobs)
+void JobTrackerModel::jobAboutToBeAdded(int pos, int parentId)
 {
-    // TODO group them by parent? It's likely that multiple jobs for the same
-    // parent will come in in the same batch, isn't it?
-#define PAIR QPair<int, int> // the parser in foreach barfs otherwise
-    Q_FOREACH (const PAIR &job, jobs) {
-        const int pos = job.first;
-        const int parentId = job.second;
-        QModelIndex parentIdx;
-        if (parentId != -1) {
-            const int row = d->rowForParentId(parentId);
-            if (row >= 0) {
-                parentIdx = createIndex(row, 0, parentId);
-            }
+    QModelIndex parentIdx;
+    if (parentId != -1) {
+        const int row = d->rowForParentId(parentId);
+        if (row >= 0) {
+            parentIdx = createIndex(row, 0, parentId);
         }
-        beginInsertRows(parentIdx, pos, pos);
-        endInsertRows();
     }
-#undef PAIR
+    beginInsertRows(parentIdx, pos, pos);
+}
+
+void JobTrackerModel::jobAdded()
+{
+    endInsertRows();
 }
 
 void JobTrackerModel::jobsUpdated(const QList< QPair< int, int > > &jobs)
 {
     // TODO group them by parent? It's likely that multiple jobs for the same
     // parent will come in in the same batch, isn't it?
-#define PAIR QPair<int, int> // the parser in foreach barfs otherwise
-    Q_FOREACH (const PAIR &job, jobs) {
+    for (const auto &job : jobs) {
         const int pos = job.first;
         const int parentId = job.second;
         QModelIndex parentIdx;
@@ -275,6 +292,5 @@ void JobTrackerModel::jobsUpdated(const QList< QPair< int, int > > &jobs)
         }
         dataChanged(index(pos, 0, parentIdx), index(pos, 3, parentIdx));
     }
-#undef PAIR
 }
 
